<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Vcard Attachments plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['addvcardmsg'] = 'Pievienot vizītkarti adrešu grāmatai';
$labels['vcardsavefailed'] = 'Nevarēja saglabāt vizītkarti';
$labels['attachvcard'] = 'Pievienot vCard';
$labels['vcardattached'] = 'vCard fails pievienots.';
$labels['vcard'] = 'vCard';
$labels['forwardvcard'] = 'Pārsūtīt vCard';
$labels['contactsattached'] = 'Šim ziņojumam ir pievienoti $num kontakti.';
$labels['importedsuccessfully'] = 'Kontakti veiksmīgi ieimportēti adrešu grāmatā.';
