<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Yeni məktubun gəlməsi haqda brauzerdə xəbər ver';
$labels['desktop'] = 'Yeni məktubun gəlməsi haqda iş masasında xəbər ver';
$labels['sound'] = 'Yeni məktubun gəlməsi haqda səs siqnalı ver';
$labels['test'] = 'Sınaq';
$labels['title'] = 'Yeni məktub!';
$labels['body'] = 'Sizə məktub gəldi';
$labels['testbody'] = 'Bu sınaq bildirişidir';
$labels['desktopdisabled'] = 'Sizin brauzerdə iş masasında bildiriş söndürülüb';
$labels['desktopunsupported'] = 'Sizin brauzer iş masasında bildiriş funksiyasını dəstəkləmir';
$labels['desktoptimeout'] = 'Masaüstü bildirişi bağla';
