<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['messagedelete'] = 'মেইল/চিঠি ছিড়ে ফেলুন';
$labels['del'] = 'ফেলে দিন';
$labels['sender'] = 'প্রেরক';
$labels['flagread'] = 'পড়';
$labels['flagflagged'] = 'দাগানো (flagged)';
$labels['notifymethodmailto'] = 'ই-মেইল/চিঠি';
$labels['datetest'] = 'তারিখ';
$labels['advancedopts'] = 'জটিল বিষয়';
$labels['vacation.subject'] = 'বিষয়';
